@@ -1,4 +1,4 @@
-#' @S3method plot CauseSpecificCox
+#' @export 
 plot.CauseSpecificCox <- function(x,
                                   cause,
                                   newdata,
@@ -14,19 +14,21 @@ plot.CauseSpecificCox <- function(x,
                                   legend=TRUE,
                                   add=FALSE,
                                   ...){
-  plot.riskRegression(x,
-                      cause=cause,
-                      newdata=newdata,
-                      xlab=xlab,
-                      ylab=ylab,
-                      xlim=xlim,
-                      ylim=ylim,
-                      lwd=lwd,
-                      col=col,
-                      lty=lty,
-                      axes=axes,
-                      percent=percent,
-                      legend=legend,
-                      add=add,
-                      ...)
+    if (missing(cause))
+        cause <- x$causes[1]
+    plot.riskRegression(x,
+                        cause=cause,
+                        newdata=newdata,
+                        xlab=xlab,
+                        ylab=ylab,
+                        xlim=xlim,
+                        ylim=ylim,
+                        lwd=lwd,
+                        col=col,
+                        lty=lty,
+                        axes=axes,
+                        percent=percent,
+                        legend=legend,
+                        add=add,
+                        ...)
 }
