@@ -6,7 +6,7 @@ timevarCoef.riskRegression <- function(object,times,...){
   }
   else{
     if (missing(times)) times <- quantile(object$time)
-    showTimes <- sindex(eval.times=times,jump.times=object$time)
+    showTimes <- prodlim::sindex(eval.times=times,jump.times=object$time)
     showMat <- cbind(times=showTimes,exp(object$timeVarCoef[showTimes,-1,drop=FALSE]))
     rownames(showMat) <- signif(object$timeVarCoef[showTimes,1],2)
     showMat
